@@ -1,7 +1,11 @@
 ##' collapse/bind several hyperSpec objects into one object
 ##'
 ##' The spectra from all objects will be put into one object.
-##' The resulting object has all wavelengths that occur in the input objects.
+##' The resulting object has all wavelengths that occur in any of the input objects, 
+##' \code{wl.tolerance} is used to determine which difference in the wavelengths is 
+##' tolerated as equal. The returned object has wavelengths rounded according to the 
+##' precision indicated by \code{wl.tolerance}. 
+##' 
 ##' Data points corresponding to wavelengths not in the original spectrum will be set to NA.
 ##' Extra data is combined in the same manner.
 ##' 
@@ -12,6 +16,7 @@
 ##' @export
 ##' @param ... hyperSpec objects to be collapsed into one object. Instead of giving several
 ##' arguments, a list with all objects to be collapsed may be given.
+##' @param wl.tolerance tolerance to decide which wavelengths are considered equal.
 ##' @aliases collapse collapse.hyperSpec
 ##' @seealso \code{\link[base]{merge}} to merge hyperSpec objects that share wavelengths but contain 
 ##'   different spectra,  \code{\link[base]{rbind}}, and  \code{\link[plyr]{rbind.fill}} for 
@@ -31,8 +36,10 @@
 ##' c
 ##' collapse (a, b, c)
 ##' 
+##' 
 
-collapse <- function (...){
+collapse <- function (..., wl.tolerance = hy.getOption ("wl.tolerance")){
+	wl.tolerance <- .checkpos (wl.tolerance, "wl.tolerance")
   dots <- list (...)
 
   ## accept also a list of hyperSpec objects
@@ -55,18 +62,32 @@ collapse <- function (...){
   labels <- labels [unique (names (labels))]
   
   ## merge data & spectra matrices
-  dots <- lapply (dots, .wl2cln)
+  
+  ## to make use of the wavelength tolerance for comparison, wavelengths are expressed as integer 
+  ## multiples of wl.tolerance. This is done by .wl2cln.
+  dots <- lapply (dots, .wl2cln, wl.tolerance)
+  
+  ## actual work of collapsing the objects
   dots <- rbind.fill (lapply (dots, slot, "data"))
-  wl <- as.numeric (colnames (dots$spc))
-
+  
+  wl <- as.numeric (colnames (dots$spc)) 
+  
+  ## back transform the integer representation of wavelength
+  wl <- wl * wl.tolerance
+  
   ## make a new hyperSpec object
   x <- new ("hyperSpec", wavelength = wl, data = dots, labels = labels)
   
   x
 }
 
-.wl2cln <- function (x){
-  colnames (x@data$spc) <- formatC (x@wavelength, digits = 17)
+.wl2cln <- function (x, wl.tolerance){
+	if (min (abs (diff (x@wavelength))) < wl.tolerance)
+		warning ("wl.tolerance (", wl.tolerance, ") larger than smallest wavelength difference within object (|", 
+						 min (diff (x@wavelength)), "|).")
+	
+	x@wavelength <- round (x@wavelength / wl.tolerance)
+	colnames (x@data$spc) <- formatC (x@wavelength, format = "f", digits = 0)
   x
 }
 
@@ -84,6 +105,23 @@ collapse <- function (...){
   tmp2 <- collapse (a = flu, b = flu)
   checkEquals (tmp, tmp2, 
                check.attributes = TRUE, check.names = TRUE, check.column.order = FALSE, check.label = TRUE)
+  
+  ## wl.tolerance
+  tmp <- flu
+  wl (tmp) <- wl (tmp) + 0.01
+  checkEqualsNumeric (nwl (collapse (tmp, flu                    )), 2 * nwl (flu))
+  checkEqualsNumeric (nwl (collapse (tmp, flu, wl.tolerance = 0.1)), nwl (flu))
+  
+  ## check warning occurs for too large tolerance
+  warnlevel <- options()$warn
+  options (warn = 2)
+  checkException (collapse (flu, wl.tolerance = 0.5 + .Machine$double.eps))
+  
+  ## bugfix: wl.tolerance generated warning for negative diff (wl (spc))
+  tmp <- flu
+  wl (tmp) <- rev (wl (tmp))
+  collapse (tmp, tmp)
+  
+  options (warn = warnlevel)
 }
 
-## FIXME: 
\ No newline at end of file
